package com.biksg.ocpsoft.dto;

import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.Serializable;

import javax.faces.application.FacesMessage;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;
import javax.imageio.ImageIO;

import org.apache.commons.io.FilenameUtils;
import org.apache.commons.io.IOUtils;
import org.primefaces.event.FileUploadEvent;
import org.primefaces.model.UploadedFile;

@ManagedBean(name = "templateProcessor")
@ViewScoped
public class TemplateProcessor implements Serializable {
  
  private static final long serialVersionUID = 3687907806292039531L;
  
  
  public void uploadLogo(FileUploadEvent event) {
    String imagePath = System.getProperty("user.dir");
    System.out.println("Current working directory : " + imagePath);
    UploadedFile uploadedFile = event.getFile();
    File file = null;
    OutputStream out = null;
    try {
      String prefix = FilenameUtils.getBaseName(uploadedFile.getFileName());
      String suffix = FilenameUtils.getExtension(uploadedFile.getFileName());
      byte[] image = uploadedFile.getContents();
      BufferedImage bi = ImageIO.read(new ByteArrayInputStream(image));
      int width = bi.getWidth();
      int height = bi.getHeight();
      if (height > 90) {
        FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_ERROR, "Failed", "Logo height is " + height
            + " pixel. It must be less than 75 pixel");
        FacesContext.getCurrentInstance().addMessage(null, msg);
      } else if (width > 300) {
        FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_ERROR, "Failed", "Logo width is " + width
            + " pixel. It must be less than 300 pixel");
        FacesContext.getCurrentInstance().addMessage(null, msg);
      } else {
        file = File.createTempFile(prefix + "_", "." + suffix, new File(imagePath));
        out = new FileOutputStream(file);
        IOUtils.copy(uploadedFile.getInputstream(), out);
        IOUtils.closeQuietly(out);
      }
    } catch (IOException e) {
      if (file != null) {
        file.delete();
      }
      FacesContext.getCurrentInstance().addMessage(null,
          new FacesMessage(FacesMessage.SEVERITY_ERROR, "Upload failed with I/O error.", null));
    } finally {
      IOUtils.closeQuietly(out);
    }
    
  }
  
}
